==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/FraudAssessment.java <==
package com.example.model;

/**
 * Model for FraudAssessment
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "FraudAssessment", description = "Model for FraudAssessment")
@javax.xml.bind.annotation.XmlRootElement(name = "FraudAssessment")
public class FraudAssessment implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.util.List<com.example.model.DataSource> dataSource = new java.util.ArrayList<com.example.model.DataSource>();
	private java.util.List<com.example.model.Overall> overall = null;
	
	/**
	 */
	public FraudAssessment dataSource(java.util.List<com.example.model.DataSource> dataSource) {
		setDataSource(dataSource);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("dataSource")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public java.util.List<com.example.model.DataSource> getDataSource() {
		return this.dataSource;
	}
	public void setDataSource(java.util.List<com.example.model.DataSource> dataSource) {
		this.dataSource = dataSource;
	}
	public FraudAssessment addDataSource(com.example.model.DataSource dataSource) {
		if (this.dataSource == null) {
			this.dataSource = new java.util.ArrayList<com.example.model.DataSource>();
		}
		this.dataSource.add(dataSource);
		return this;
	}
	
	/**
	 */
	public FraudAssessment overall(java.util.List<com.example.model.Overall> overall) {
		setOverall(overall);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("overall")
	@javax.validation.Valid
	public java.util.List<com.example.model.Overall> getOverall() {
		return this.overall;
	}
	public void setOverall(java.util.List<com.example.model.Overall> overall) {
		this.overall = overall;
	}
	public FraudAssessment addOverall(com.example.model.Overall overall) {
		if (this.overall == null) {
			this.overall = new java.util.ArrayList<com.example.model.Overall>();
		}
		this.overall.add(overall);
		return this;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		FraudAssessment fraudAssessment = (FraudAssessment) o;
		return java.util.Objects.equals(this.dataSource, fraudAssessment.dataSource)
				&& java.util.Objects.equals(this.overall, fraudAssessment.overall);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.dataSource, this.overall);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class FraudAssessment {\n");
		
		sb.append("    dataSource: ").append(toIndentedString(this.dataSource)).append("\n");
		sb.append("    overall: ").append(toIndentedString(this.overall)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/FraudAssessment.java <==
package com.example.model;

/**
 * Model for FraudAssessment
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "FraudAssessment", description = "Model for FraudAssessment")
@javax.xml.bind.annotation.XmlRootElement(name = "FraudAssessment")
public class FraudAssessment implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.util.List<com.example.model.DataSource> dataSource = new java.util.ArrayList<com.example.model.DataSource>();
	private java.util.List<com.example.model.Overall> overall = null;
	
	/**
	 */
	public FraudAssessment dataSource(java.util.List<com.example.model.DataSource> dataSource) {
		setDataSource(dataSource);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "dataSource")
	@com.fasterxml.jackson.annotation.JsonProperty("dataSource")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public java.util.List<com.example.model.DataSource> getDataSource() {
		return this.dataSource;
	}
	public void setDataSource(java.util.List<com.example.model.DataSource> dataSource) {
		this.dataSource = dataSource;
	}
	public FraudAssessment addDataSource(com.example.model.DataSource dataSource) {
		if (this.dataSource == null) {
			this.dataSource = new java.util.ArrayList<com.example.model.DataSource>();
		}
		this.dataSource.add(dataSource);
		return this;
	}
	
	/**
	 */
	public FraudAssessment overall(java.util.List<com.example.model.Overall> overall) {
		setOverall(overall);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "overall")
	@com.fasterxml.jackson.annotation.JsonProperty("overall")
	@javax.validation.Valid
	public java.util.List<com.example.model.Overall> getOverall() {
		return this.overall;
	}
	public void setOverall(java.util.List<com.example.model.Overall> overall) {
		this.overall = overall;
	}
	public FraudAssessment addOverall(com.example.model.Overall overall) {
		if (this.overall == null) {
			this.overall = new java.util.ArrayList<com.example.model.Overall>();
		}
		this.overall.add(overall);
		return this;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		FraudAssessment fraudAssessment = (FraudAssessment) o;
		return java.util.Objects.equals(this.dataSource, fraudAssessment.dataSource)
				&& java.util.Objects.equals(this.overall, fraudAssessment.overall);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.dataSource, this.overall);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class FraudAssessment {\n");
		
		sb.append("    dataSource: ").append(toIndentedString(this.dataSource)).append("\n");
		sb.append("    overall: ").append(toIndentedString(this.overall)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
